/* This file was generated by syncqt. */
#ifndef QT_QTDESIGNERCOMPONENTS_VERSION_H
#define QT_QTDESIGNERCOMPONENTS_VERSION_H

#define QTDESIGNERCOMPONENTS_VERSION_STR "5.9.2"

#define QTDESIGNERCOMPONENTS_VERSION 0x050902

#endif // QT_QTDESIGNERCOMPONENTS_VERSION_H
